@@ -8,10 +8,10 @@ import click
 from dotenv import find_dotenv, load_dotenv
 from tqdm import tqdm
 
-from src.models.utils import init_tokenizer, mask_tokens
 import pandas as pd
+from src.models.utils import init_tokenizer, mask_tokens
 
-fileConfig('src/log_config.ini')
+fileConfig('log_config.ini')
 logger = logging.getLogger(__name__)
 
 
@@ -23,7 +23,6 @@ def main(input_filepath, output_filepath, model_name):
     """ Runs data processing scripts to turn raw data from (../raw) into
         cleaned data ready to be analyzed (saved in ../processed).
     """
-    logger = logging.getLogger(__name__)
     logger.info('making final data set from raw data')
     tokenizer = init_tokenizer(model_name)
     for file_path in tqdm(glob.glob(input_filepath + '/*.txt'),
